Bioinformatics Toolbox

# MAGICAL Explorer

Interactive visualization for regulatory circuit inference results.

Drop your MAGICAL output (.txt) here

or click to select a file

0
Total Circuits
0
Unique Genes
0
Active TFs

## Regulatory Influence Landscape

## Confidence Distribution

Gene | TF Name | Circuit Confidence | Effect | Peak Location | Looping (L) Dir | Binding (B) Dir
--- | --- | --- | --- | --- | --- | ---